# Flax Examples

Each example is designed to be **self-contained and easily forkable**, while
reproducing relevant results in different areas of machine learning.

As discussed in [#231](https://github.com/google/flax/issues/231), we decided
to go for a standard pattern for all examples including the simplest ones
(like MNIST). This makes every example a bit more verbose, but once you know
one example, you know the structure of all of them. Having unit tests and
integration tests is also very useful when you fork these examples.

For more examples including contributions from the community and other projects currently using Flax see the **[Examples](https://flax.readthedocs.io/en/latest/examples.html)** section in the documentation.
